# file generated by setuptools-scm
# don't change, don't track in version control

from dariko.config import set_config
from dariko.driver import ask, ask_batch, ValidationError

__version__ = "0.2.2"
__version_tuple__ = (0, 2, 2)
version = __version__
version_tuple = __version_tuple__

__all__ = [
    "set_config",
    "ask",
    "ask_batch",
    "ValidationError",
    "__version__",
    "__version_tuple__",
    "version",
    "version_tuple",
]

TYPE_CHECKING = False
if TYPE_CHECKING:
    from typing import Union

    VERSION_TUPLE = tuple[Union[int, str], ...]
